@@ -22,8 +22,6 @@ defaults = {
     "SQLALCHEMY_ECHO": False,
     "SQLALCHEMY_TRACK_MODIFICATIONS": True,
     "batch-filter-root": "/app/fk/batch/filters",
-    "overwatch-password": unset,
-    "overwatch-user": unset,
     "cache-dir-name": "_cache",
     "crawler-html-parser": "html5lib",
     "crawler-referer": "https://www.shopify.com/",
@@ -44,12 +42,12 @@ defaults = {
     "influx-username": unset,
     "n2report-dir-name": "_n2report",
     "n2report-index-name": "index.html",
+    "overwatch-password": unset,
+    "overwatch-user": unset,
     "preferred-url-scheme": "http",
     "printful-api-endpoint": "https://api.printful.com/",
     "printful-api-key": unset,
     "printful-api-key-base64": unset,
-    "project": "Bonkers Sales Pop",
-    "project-root": "/app",
     "screenshots-dir-name": "_screenshots",
     "screenshots-index-name": "screenshots.html",
     "shop-id-generator-batch-size": 200,
@@ -58,17 +56,18 @@ defaults = {
     "shop-id-thread-count": 300,
     "shopify-api-key": unset,
     "shopify-api-secret": unset,
-    "shopify-api-version": "2020-10",
     "shopify-api-throttle-limit": 1,
     "shopify-api-throttle-period": 3000,
-    "shopify-app-name": "The name of this app",
-    "shopify-app-description": "The description of this app",
+    "shopify-api-version": "2020-10",
     "shopify-app-author": "The author of this app",
     "shopify-app-author-email": "The email of the author of this app",
+    "shopify-app-company-name": "The name of the company behind this app",
+    "shopify-app-company-website": "The url fo the company website",
+    "shopify-app-description": "The description of this app",
+    "shopify-app-name": "The name of this app",
     "shopify-app-preferred-url-scheme": "https",
     "shopify-password": unset,
     "shopify-shared-secret": unset,
-    "shopify-shop-name": "",
     "static-files-root": "/app/shopify_app/static",
     "webdriver-max-windows": 5,
     "webdriver-url": "http://127.0.0.1:4444/wd/hub",
