@@ -292,10 +292,8 @@ def read_file(fname, strip=True):
         logger.error(f"Could not find file {fn} relative to working directory {os.getcwd()}")
     return data
 
-def write_file(fname, data, strip=True):
-    fn = os.path.join(os.path.dirname(os.path.abspath(__file__)), fname)
-    data = ""
-    with open(fn, "w", encoding="utf-8") as f:
+def write_file(fn, data, strip=True):
+    with open(fn, "w") as f:
         f.write(data.strip() if strip else data)
 
 def debug_imports():
